Range-v3: ranges::v3::concepts::IndirectlyMovableStorable Struct Reference

Range-v3 Range algorithms, views, and actions for the Standard Library |

Public Member Functions | List of all members
ranges::v3::concepts::IndirectlyMovableStorable Struct Reference
Inheritance diagram for ranges::v3::concepts::IndirectlyMovableStorable:

## Public Member Functions
template<typename I , typename O >
auto | requires_ () -> decltype(concepts::valid_expr(concepts::model_of< Movable, Readable::value_t< I >>(), concepts::model_of< Constructible, Readable::value_t< I >, Readable::rvalue_reference_t< I >>(), concepts::model_of< Assignable, Readable::value_t< I > &, Readable::rvalue_reference_t< I >>(), concepts::model_of< Writable, O, Readable::value_t< I >>()))
Public Member Functions inherited from ranges::v3::concepts::refines< IndirectlyMovable >
void | requires_ ()

## Additional Inherited Members
Public Types inherited from ranges::v3::concepts::refines< IndirectlyMovable >
using | base_concepts_t = meta::list< Concepts... >